@@ -8,11 +8,15 @@ from nomenklatura.matching.erun.model import EntityResolveRegression
 from nomenklatura.matching.erun.train import train_matcher as train_erun_matcher
 from nomenklatura.matching.logic_v1.model import LogicV1
 from nomenklatura.matching.logic_v2.model import LogicV2
+from nomenklatura.matching.logic_v3.model import LogicV3
+from nomenklatura.matching.logic_v4.model import LogicV4
 from nomenklatura.matching.types import ScoringAlgorithm, ScoringConfig
 
 ALGORITHMS: List[Type[ScoringAlgorithm]] = [
     LogicV1,
     LogicV2,
+    LogicV3,
+    LogicV4,
     NameMatcher,
     NameQualifiedMatcher,
     RegressionV1,
@@ -44,4 +48,7 @@ __all__ = [
     "ScoringConfig",
     "LogicV1",
     "LogicV2",
+    "LogicV3",
+    "LogicV4",
+    "SVMV1",
 ]
